@@ -1,6 +1,10 @@
 require "spec_helper"
 require 'fast_gettext/translation_repository/base'
 
+require 'active_record'
+require 'fast_gettext/translation_repository/db'
+FastGettext::TranslationRepository::Db.require_models
+
 describe 'Storage' do
   include FastGettext::Storage
 
@@ -307,6 +311,13 @@ describe 'Storage' do
       FastGettext.reload!
     end
 
+    it "works with DB repository" do
+      db = FastGettext::TranslationRepository::Db.new('x', :model=>TranslationKey)
+      self.translation_repositories[:db] = db
+
+      FastGettext.reload!
+    end
+
     it "clears the cache" do
       FastGettext.cache.should_receive(:reload!)
 
